# Define the kmod package name here.
%define  kmod_name xfs

Name:    %{kmod_name}-kmod
Version: 0.4
Release: 2.el4
Group:   System Environment/Kernel
License: GPL
Summary: %{kmod_name} kernel modules
URL:     http://oss.sgi.com/projects/xfs

BuildRoot:     %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
ExclusiveArch: i586 i686 x86_64

# Sources.
Source0:  %{kmod_name}-kern.tar.gz
Source10: kmodtool-%{kmod_name}

# If kversion isn't defined on the rpmbuild line, build for the current kernel.
%{!?kversion: %define kversion %(uname -r)}

# Define the variants for each architecture.
%define upvar ""
%define smpvar  smp
%ifarch i686
%define hugememvar hugemem
%define xenvar xenU
%endif
%ifarch x86_64
%define largesmpvar largesmp
%define xenvar xenU
%endif

# If kvariants isn't defined on the rpmbuild line, build all variants for this architecture.
%{!?kvariants: %define kvariants %{?upvar} %{?smpvar}  %{?xenvar} %{?hugememvar} %{?largesmpvar}}

Source1         : config.xfs

# Allow the code to build as an out-of-tree module
Patch0          : xfs_ootbuild.patch

# Update patches from the sles9 kernel since first release
Patch1          : xfs-kern-202363a-fix-xfs_finish_reclaim_all-umount-deadlock
Patch2          : xfs-log-diag
Patch3          : xfs-kern-25238a-quota-trans-diag
Patch4          : xfs-ftruncate-stale-data
Patch5          : xfs-kern-930841-default_acl_enospc_fix
Patch6          : xfs-kern-25687a-sles9sp3-iunpin-reclaim-fix
Patch7          : xfs-kern-26040a-do-not-dirty-inode-being-freed
Patch8          : xfs-kern-26347a-fix-race-on-link

# This patchset is for making the xfs codebase in sles9 work
# with an RHEL4 kernel.
Patch100        : xfs-version.patch
Patch101        : xfs_qsort.patch
Patch102        : xfs_proc_args.patch
Patch103        : xfs_export_ops.patch
Patch104        : xfs_write_inode_return.patch
Patch105        : xfs_dmapi_address_space.patch
# Needed for kernels < 2.6.9-42.EL, uncomment below
Patch106        : xfs_direct_io_locking.patch

# Magic hidden here.
%define kmodtool sh %{SOURCE10}
%{expand:%(%{kmodtool} rpmtemplate_kmp %{kmod_name} %{kversion} %{kvariants} 2>/dev/null)}

%description
The XFS(tm) Filesystem from Silicon Graphics, Inc.
XFS is a highly scalable, high-performance journaling filesystem that provides
rapid recovery from system crashes.

%prep
%setup -q -c -T -a 0

pushd %{kmod_name}
cp %{SOURCE1} .
# build glue
%patch0 -p1

%patch1 -p3
%patch2 -p3
%patch3 -p3
%patch4 -p3
%patch5 -p3
%patch6 -p3
%patch7 -p3
%patch8 -p3

%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
#%%patch106 -p1

echo "#define XFS_VERSION_STRING \"SGI XFS from %{name}-%{version}-%{release} rpm\"" > linux-2.6/xfs_module_version.h

popd

for kvariant in %{kvariants} ; do
    cp -a %{kmod_name} _kmod_build_$kvariant
done

%build
for kvariant in %{kvariants} ; do
#    ksrc=%{_usrsrc}/kernels/%{kversion}${kvariant:+-$kvariant}-%{_target_cpu}
#    pushd _kmod_build_$kvariant
#    make -C "${ksrc}" modules M=$PWD
#    popd
    ksrc=/lib/modules/"%{kversion}${kvariant:+$kvariant}"/build
    cd _kmod_build_$kvariant
    # make TOPDIR=${ksrc} modules %{?_smp_mflags}
    make -C "${ksrc}" OOT_BUILD=y SUBDIRS=${PWD} modules %{?_smp_mflags}
    cd ..

done

%install
export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
export INSTALL_MOD_DIR=extra/%{kmod_name}
for kvariant in %{kvariants} ; do
#    ksrc=%{_usrsrc}/kernels/%{kversion}${kvariant:+-$kvariant}-%{_target_cpu}
#    pushd _kmod_build_$kvariant
#    make -C "${ksrc}" modules_install M=$PWD
#    install -d ${INSTALL_MOD_PATH}/usr/lib/debug
#    popd
    ksrc=/lib/modules/"%{kversion}${kvariant:+$kvariant}"/build
    cd _kmod_build_$kvariant
    make -C ${ksrc} OOT_BUILD=y SUBDIRS=`pwd` modinst_dir=$RPM_BUILD_ROOT//lib/modules/"%{kversion}${kvariant:+$kvariant}"/extra/%{kmod_name}  modules_install
    # make TOPDIR=${ksrc} INSTALL_MOD_PATH=$RPM_BUILD_ROOT INSTALL_MOD_DIR=extra/%{kmod_name}/ modules_install %{?_smp_mflags}
    cd ..

done
# Strip the module(s).
find ${INSTALL_MOD_PATH} -type f -name \*.ko -exec strip --strip-debug \{\} \;
#

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Wed Feb 25 2009 Akemi Yagi <toracat@centos.org> 0.4-2
- Initial build of the kABI-tracking version from 0.4-1.
- Modified spec and kmodtool(-xfs)
- Note: weak-modules became available as of CentOS-4.7
- Strip the module(s) added

* Tue May 22 2007 Johnny Hughes  <johnny@centos.org> 0.4-1
- Modified this version of the spec to work with el4.

* Thu Apr 19 2007 Johnny Hughes <johnny@centos.org> 0.3-2
- Modified kmodtool (Source10) to remove the requirement for xfs-kmod-common

* Tue Apr 17 2007 Johnny Hughes <johnny@centos.org>
- Initial use in CentOS-5
- Added paevar and modified paevar, smpvar, xenvar, xdumpvar to follow
  EL5 and not FC6 naming conventions.

